@@ -14,11 +14,11 @@
 #include "actionmanager.h"
 #include "akonadicollectionview.h"
 #include "calendaradaptor.h"
+#include "calendarinterfaceadaptor.h"
 #include "calendarview.h"
 #include "kocore.h"
 #include "kodialogmanager.h"
 #include "koglobals.h"
-#include "korgacinterface.h"
 #include "korganizeradaptor.h"
 #include "koviewmanager.h"
 #include "kowindowlist.h"
@@ -33,12 +33,12 @@
 
 #include <IncidenceEditor/IncidenceEditorSettings>
 
-#include <Akonadi/Calendar/History>
-#include <Akonadi/Calendar/ICalImporter>
 #include <Akonadi/ETMViewStateSaver>
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityTreeModel>
 #include <Akonadi/EntityTreeView>
+#include <Akonadi/History>
+#include <Akonadi/ICalImporter>
 
 #include <KCalendarCore/FileStorage>
 #include <KCalendarCore/ICalFormat>
@@ -74,6 +74,7 @@
 #include <QStandardPaths>
 #include <QTimer>
 #include <QToolBar>
+#include <QWindow>
 
 KOWindowList *ActionManager::mWindowList = nullptr;
 
@@ -87,6 +88,9 @@ ActionManager::ActionManager(KXMLGUIClient *client,
     : QObject(parent)
 {
     new KOrgCalendarAdaptor(this);
+
+    // reminder daemon interface
+    new CalendarInterfaceAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Calendar"), this);
 
     mGUIClient = client;
@@ -711,7 +715,7 @@ void ActionManager::initActions()
 
 void ActionManager::updateHamburgerMenu()
 {
-    QMenu *menu = new QMenu;
+    auto menu = new QMenu;
 
     menu->addAction(mACollection->action(QStringLiteral("conf_datetime")));
     menu->addSeparator();
@@ -988,14 +992,6 @@ void ActionManager::updateConfig()
 
     KOCore::self()->reloadPlugins();
 
-    /* Hide/Show the Reminder Daemon */
-    org::kde::korganizer::KOrgac korgacInterface{QStringLiteral("org.kde.korgac"), QStringLiteral("/ac"), QDBusConnection::sessionBus()};
-    if (!KOPrefs::instance()->mShowReminderDaemon) {
-        korgacInterface.hide();
-    } else {
-        korgacInterface.show();
-    }
-
 #ifdef AKONADI_PORT_DISABLED // shouldn't be required anymore
     if (mCollectionView) {
         mCollectionView->updateView();
@@ -1103,6 +1099,20 @@ bool ActionManager::showIncidenceContext(Akonadi::Item::Id id)
     return mCalendarView->showIncidenceContext(id);
 }
 
+void ActionManager::showIncidenceByUid(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken)
+{
+    mCalendarView->showIncidenceByUid(uid);
+    mCalendarView->showDate(occurrence.date());
+
+    KWindowSystem::setCurrentXdgActivationToken(xdgActivationToken);
+    KOrg::MainWindow *mainWindow = ActionManager::findInstance(QUrl());
+    if (mainWindow) {
+        KWindowSystem::activateWindow(mainWindow->topLevelWidget()->windowHandle());
+        mainWindow->topLevelWidget()->show();
+        mainWindow->topLevelWidget()->windowHandle()->raise();
+    }
+}
+
 bool ActionManager::handleCommandLine(const QStringList &args)
 {
     QCommandLineParser parser;
@@ -1203,9 +1213,7 @@ QString ActionManager::localFileName() const
 class ActionManager::ActionStringsVisitor : public KCalendarCore::Visitor
 {
 public:
-    ActionStringsVisitor()
-    {
-    }
+    ActionStringsVisitor() = default;
 
     bool act(KCalendarCore::IncidenceBase::Ptr incidence, QAction *show, QAction *edit, QAction *del)
     {
@@ -1322,7 +1330,7 @@ Akonadi::Collection ActionManager::selectedCollection() const
 {
     const QModelIndex index = mCollectionView->view()->currentIndex();
     if (!index.isValid()) {
-        return Akonadi::Collection();
+        return {};
     }
 
     return index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
