@@ -19,7 +19,7 @@
 #include <KCalendarCore/ScheduleMessage>
 #include <KCalendarCore/Visitor>
 
-#include <Akonadi/Calendar/ITIPHandler>
+#include <Akonadi/ITIPHandler>
 
 #include <CalendarSupport/MessageWidget>
 
@@ -68,9 +68,7 @@ public:
     class Factory
     {
     public:
-        virtual ~Factory()
-        {
-        }
+        virtual ~Factory() = default;
 
         virtual CalendarViewExtension *create(QWidget *parent) = 0;
     };
@@ -99,9 +97,7 @@ public:
     class CalendarViewVisitor : public KCalendarCore::Visitor
     {
     public:
-        CalendarViewVisitor()
-        {
-        }
+        CalendarViewVisitor() = default;
 
         bool act(KCalendarCore::IncidenceBase::Ptr &incidence, CalendarView *view)
         {
@@ -307,6 +303,12 @@ public Q_SLOTS:
     void showIncidenceContext(const Akonadi::Item &incidence);
     bool showIncidenceContext(Akonadi::Item::Id id);
 
+    /**
+      Show an incidence in context, given its uid.
+      @param uid the iCal uid of the incidence to show.
+    */
+    void showIncidenceByUid(const QString &uid);
+
     /** Create an editor for the supplied incidence. It calls the correct editXXX method*/
     bool editIncidence(const Akonadi::Item &item, bool isCounter = false) override;
     bool editIncidence(Akonadi::Item::Id id);
