@@ -10,7 +10,7 @@
 #pragma once
 
 #include "baseview.h"
-#include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/ETMCalendar>
 
 namespace KOrg
 {
@@ -26,9 +26,7 @@ public:
     {
     }
 
-    ~CalendarViewBase() override
-    {
-    }
+    ~CalendarViewBase() override = default;
 
     virtual Akonadi::ETMCalendar::Ptr calendar() const = 0;
     virtual Akonadi::IncidenceChanger *incidenceChanger() const = 0;
